PxHUD = LibStub("AceAddon-3.0"):NewAddon("PxHUD", "AceConsole-3.0", "AceEvent-3.0")

PxHUD.L = LibStub("AceLocale-3.0"):GetLocale("PxHUD", false)

local L = PxHUD.L
local bEnabled = false
local TexturePath = "Interface\\AddOns\\PxHUD\\images\\"

function PxHUD:OnInitialize()
	self.defaults = {
		profile = {
			barWidth = 100,
			barHeight = 300,
			barTexture = "CleanCurves",
			bgBlendMode = "Blend",
			barBlendMode = "Blend",
			gap = 100,
		}
	}
	self.db = LibStub("AceDB-3.0"):New("PxHUDDB", self.defaults)
	self.settings = self.db.profile
	
	self.PxHUDFrame = CreateFrame("Frame", "PxHUDFrame", UIParent)
	self.PxHUDFrame:SetFrameStrata("BACKGROUND")
	self.PxHUDFrame:SetWidth(self.settings.gap)
	self.PxHUDFrame:SetHeight(20)
	self.PxHUDFrame:ClearAllPoints()
	self.PxHUDFrame:SetPoint("CENTER", 0, -1 * self.settings.barHeight / 2)

	LibStub("AceConfig-3.0"):RegisterOptionsTable("PxHUD", self:GetOptions(), {"pxhud", "px"})
end

function PxHUD:OnEnable()
	bEnabled = true

	for name,module in PxHUD:IterateModules() do
		if module.OnModuleEnable then
			module:OnModuleEnable()
		end
	end
end

function PxHUD:OnDisable()
	bEnabled = false

	for name,module in PxHUD:IterateModules() do
		if module.OnModuleDisable then
			module:OnModuleDisable()
		end
	end
end

function PxHUD:GetOptions()
	return {
		name = "PxHUD",
		handler = PxHUD,
		type = "group",
		args = {
			show = {
				type = 'execute',
				name = L["Show options window"],
				desc = L["Shows the PxHUD options window"],
				func = function()
				end,
			},
		},
	}
end

function PxHUD:Debug(str)

end

function PxHUD:GetFullTexturePath(texture)
	return TexturePath .. texture
end

function PxHUD:CreateBar(name)
	if name == nil then
		self:Debug("Provided a nil name to CreateBar")
		return
	end

	local frame = self:CreateBarBackgroundFrame(frame, name)
	frame = self:CreateBarFrame(frame, name)
	
	return frame
end

function PxHUD:CreateBarBackgroundFrame(frame, name)
	if frame == nil then
		frame = CreateFrame("Frame", "PxHUD_"..name.."_BG", self.PxHUDFrame)
	end

	frame:ClearAllPoints()
	frame:SetPoint("BOTTOMLEFT", frame:GetParent(), "BOTTOMLEFT", 0, 0)
	frame:SetFrameStrata("BACKGROUND")
	frame:SetHeight(self.settings.barHeight)
	frame:SetWidth(self.settings.barWidth)

	if frame.bg == nil then
		frame.bg = frame:CreateTexture(nil, "BACKGROUND")
	end

	frame.bg:SetTexture(self:GetFullTexturePath(self.settings.barTexture .. "BG"))
	frame.bg:SetBlendMode(self.settings.bgBlendMode)
	frame.bg:ClearAllPoints()
	frame.bg:SetPoint("BOTTOMLEFT", frame, "BOTTOMLEFT")
	frame.bg:SetPoint("BOTTOMRIGHT", frame, "BOTTOMRIGHT")
	frame.bg:SetHeight(self.settings.barHeight)
	--if (self.moduleSettings.side == IceCore.Side.Left) then
		frame.bg:SetTexCoord(1, 0, 0, 1)
	--else
	--	frame.bg:SetTexCoord(0, 1, 0, 1)
	--end
	
	return frame
end

function PxHUD:CreateBarFrame(frame, name)
	if frame == nil then
		return
	end
	
	if frame.barFrame == nil then
		frame.barFrame = CreateFrame("Frame", "PxHUD_"..name, frame)
	end

	frame.barFrame:SetFrameStrata("LOW")
	frame.barFrame:ClearAllPoints()
	--if (self.moduleSettings.reverse) then
	--	frame.barFrame:SetPoint("TOPLEFT", frame, "TOPLEFT")
	--else
		frame.barFrame:SetPoint("BOTTOMLEFT", frame, "BOTTOMLEFT")
	--end
	frame.barFrame:SetWidth(self.settings.barWidth)
	frame.barFrame:SetHeight(self.settings.barHeight)

	if frame.barFrame.bar == nil then
		frame.barFrame.bar = frame.barFrame:CreateTexture(nil, "ARTWORK")
	end
	frame.barFrame.bar:SetTexture(self:GetFullTexturePath(self.settings.barTexture))
	frame.barFrame.bar:SetBlendMode(self.settings.barBlendMode)
	frame.barFrame.bar:SetAllPoints(frame.barFrame)
	--if (self.moduleSettings.side == IceCore.Side.Left) then
		frame.barFrame.bar:SetTexCoord(1, 0, 0, 1)
	--else
	--	self.barFrame.bar:SetTexCoord(0, 1, min_y, max_y)
	--end
end
